@@ -16,7 +16,7 @@
 package Tk::JFileDialog;
 
 use vars qw($VERSION $bummer $MAXWIDTH);
-our $VERSION = '2.20';
+our $VERSION = '2.30';
 our $MAXWIDTH = 60;  #AVG. CHARACTERS.
 
 require 5.002;
@@ -26,10 +26,13 @@ use Carp;
 use Cwd;
 use File::Glob;
 use Tk;
-use Tk::Dialog;
 use Tk::JBrowseEntry;
 
 my $useAutoScroll = 0;
+my $bummer;
+my $dialog_widget = 'Dialog';
+
+eval 'use Tk::JDialog; $dialog_widget = "JDialog"; 1';
 eval 'use Tk::Autoscroll; $useAutoScroll = 1; 1';
 
 BEGIN
@@ -48,6 +51,8 @@ no strict 'subs';
 	}
 }
 
+eval 'use Tk::Dialog; 1'  if ($dialog_widget !~ 'J');
+
 my $driveletter = '';
 my %lastPaths;
 my $homedir = $bummer ? $ENV{'HOMEDRIVE'} . $ENV{'HOMEPATH'} : $ENV{'HOME'};
@@ -108,6 +113,7 @@ sub Populate
 		{
 			$FDialog->{'Can'}->invoke  if (defined($FDialog->{'Can'}) && $FDialog->{'Can'}->IsWidget);
 		});
+		$FDialog->transient($FDialog->Parent->toplevel);
 	}
 	## Initialize variables that won't be initialized later
 	$FDialog->{'Retval'} = -1;
@@ -1435,7 +1441,9 @@ sub RescanFiles
 		my @fpatList;
 		$fl->delete(0,'end');
 
-		($_ = defined($self->{'Configure'}{'-FPat'}) ? $self->{'Configure'}{'-FPat'} : '') =~ s/^\s*|\s*$//o;
+		($_ = defined($self->{'Configure'}{'-FPat'}) ? $self->{'Configure'}{'-FPat'} : '');
+		s/^\s+$//;
+		s/\s+$//;
 		if (defined $self->{'Configure'}{'-FPatList'})
 		{
 			$self->{'Configure'}{'-FPat'} = $_ = ${$self->{'Configure'}{'-FPatList'}}[0]  if ((!$_ || /^\*$/o)
@@ -1460,8 +1468,21 @@ sub RescanFiles
 		$self->{'FPat'}->choices(\@fpatList)  if ($#fpatList > 0);
 
 		$self->{'Configure'}{'-FPatFilters'} = $_  if ($self->{'Configure'}{'-FPatOnly'});
-		my @filters = split(/\|/o, $_);
+		(my $protected = $_) =~ s#\\\|#\x04#g;
+		my @filters = split(/\|/o, $protected);
 		@filters = ('')  unless ($#filters >= 0);
+		my @filters_rgx = ();
+		foreach my $f (@filters)
+		{
+			$f =~ s#\x04#\|#g;     #UNPROTECT AND UNESCAPE ESCAPED SEPARATOR ("\|").
+			$f =~ s#\\\.#\x02#go;  #PROTECT ESCAPED SPECIAL CHARACTERS:
+			$f =~ s#\\\*#\x03#go;
+			$f =~ s#\.#\\\.#go;    #CONVERT PATTERN TO PROPER PERL REGEX:
+			$f =~ s#\*#\.\*#go;    #("*" MUST BE ".*", SO WE TREAT "\*" AS "*")!
+			$f =~ s#\x03#\\\*#go;  #UNPROTECT ESCAPED SPECIAL CHARACTERS:
+			$f =~ s#\x02#\.#go;    #(WE TREAT "." AS "\." (MATCH ".") AND "\." AS "." (WILDCARD))!
+			push @filters_rgx, $f;
+		}
 		undef @allfiles;
 
 		#WE'LL EITHER LOAD FILES FROM A USER-PROVIDED LIST -OR- FROM THE CURRENT PATH:
@@ -1514,7 +1535,7 @@ FILELOOP1:			foreach my $f (@{$self->{'Configure'}{'-FNameList'}})  #USER-PROVID
 					push @allfiles, $_;
 					next;
 				}
-				foreach my $filter (@filters)
+				foreach my $filter (@filters_rgx)
 				{
 					if (/^${filter}$/)
 					{
@@ -1539,7 +1560,7 @@ FILELOOP2:			while ($_ = readdir(DIR))
 					push @allfiles, $_;
 					next;
 				}
-				foreach my $filter (@filters)
+				foreach my $filter (@filters_rgx)
 				{
 					if (/^${filter}$/)
 					{
@@ -1735,11 +1756,11 @@ sub GetReturn
 				elsif ($self->{'Configure'}{'-Create'} <= 0 && !$self->_fidtest('-d', $fname))
 				{
 					## Put up no create allowed dialog
-					$self->{'Configure'}{'-EDlgText'} = "You must specify an existing folder.\n($fname not found)";
-					$self->Dialog(-title => $self->{'Configure'}{'-EDlgTitle'},
-							-text => $self->{'Configure'}{'-EDlgText'},
+					$self->{'Configure'}{'-EDlgText'} = "You must specify an existing folder.\n(\$fname not found)";
+					eval "\$self->${dialog_widget}(-title => \$self->{'Configure'}{'-EDlgTitle'},
+							-text => \$self->{'Configure'}{'-EDlgText'},
 							-bitmap => 'error'
-					)->Show;
+					)->Show";
 
 					return;
 				}
@@ -1753,17 +1774,30 @@ sub GetReturn
 				{
 					$self->{'Configure'}{'-EDlgText'} = "Only a single file is allowed!\n" 
 							. $self->{'Configure'}{'-File'} . "\nrepresents multiple files.";
-					$self->Dialog(-title => $self->{'Configure'}{'-EDlgTitle'},
-								-text => $self->{'Configure'}{'-EDlgText'},
+					eval "\$self->${dialog_widget}(-title => \$self->{'Configure'}{'-EDlgTitle'},
+								-text => \$self->{'Configure'}{'-EDlgText'},
 								-bitmap => 'error'
-					)->Show;
+					)->Show";
 
 					return;
 				}
 				my $filenames = '';
 				my $errnames = '';
-				my @filters = split (/\|/o, $self->{'Configure'}{'-FPatFilters'});
+				(my $protected = $self->{'Configure'}{'-FPatFilters'}) =~ s#\\\|#\x04#g;
+				my @filters = split (/\|/o, $protected);
 				@filters = ('')  unless ($#filters >= 0);
+				my @filters_rgx = ();
+				foreach my $f (@filters)
+				{
+					$f =~ s#\x04#\|#g;     #UNPROTECT AND UNESCAPE ESCAPED SEPARATOR ("\|").
+					$f =~ s#\\\.#\x02#go;  #PROTECT ESCAPED SPECIAL CHARACTERS:
+					$f =~ s#\\\*#\x03#go;
+					$f =~ s#\.#\\\.#go;    #CONVERT PATTERN TO PROPER PERL REGEX:
+					$f =~ s#\*#\.\*#go;    #("*" MUST BE ".*", SO WE TREAT "\*" AS "*")!
+					$f =~ s#\x03#\\\*#go;  #UNPROTECT ESCAPED SPECIAL CHARACTERS:
+					$f =~ s#\x02#\.#go;    #(WE TREAT "." AS "\." (MATCH ".") AND "\." AS "." (WILDCARD))!
+					push @filters_rgx, $f;
+				}
 FILELOOP3:				foreach my $f (@filelist)   #ADD FULL PATHS TO ANY THAT ARE MISSING PATHS!:
 				{
 					$f =~ s#\\#\/#go;
@@ -1785,7 +1819,7 @@ FILELOOP3:				foreach my $f (@filelist)   #ADD FULL PATHS TO ANY THAT ARE MISSIN
 							$filenames .= $f . ',';
 							next;
 						}
-						foreach my $filter (@filters)
+						foreach my $filter (@filters_rgx)
 						{
 							if ($f =~ /^${filter}$/)
 							{
@@ -1820,9 +1854,9 @@ FILELOOP3:				foreach my $f (@filelist)   #ADD FULL PATHS TO ANY THAT ARE MISSIN
 							if ($self->{'Configure'}{'-SelectMode'} =~ /(?:multiple|extended)/i);
 					$self->{'Configure'}{'-EDlgText'} = "You must specify ${errdesc}.\n"
 							. "($errnames)";
-					$self->Dialog(-title => $self->{'Configure'}{'-EDlgTitle'},
-							-text => $self->{'Configure'}{'-EDlgText'},
-							-bitmap => 'error')->Show;
+					eval "\$self->${dialog_widget}(-title => \$self->{'Configure'}{'-EDlgTitle'},
+							-text => \$self->{'Configure'}{'-EDlgText'},
+							-bitmap => 'error')->Show";
 
 					return;
 				}
@@ -1837,10 +1871,10 @@ FILELOOP3:				foreach my $f (@filelist)   #ADD FULL PATHS TO ANY THAT ARE MISSIN
 			{
 				## Put up no create allowed dialog
 				$self->{'Configure'}{'-EDlgText'} = "You must specify an existing folder.\n($fname not found)";
-				$self->Dialog(-title => $self->{'Configure'}{'-EDlgTitle'},
-						-text => $self->{'Configure'}{'-EDlgText'},
+				eval "\$self->${dialog_widget}(-title => \$self->{'Configure'}{'-EDlgTitle'},
+						-text => \$self->{'Configure'}{'-EDlgText'},
 						-bitmap => 'error'
-				)->Show;
+				)->Show";
 
 				$fname =~ s/ file(\W*)$/ directory$1/i;
 				return;
@@ -1879,11 +1913,11 @@ FILELOOP3:				foreach my $f (@filelist)   #ADD FULL PATHS TO ANY THAT ARE MISSIN
 				elsif ($self->{'Configure'}{'-Create'} <= 0 && !$self->_fidtest('-d', $fname))
 				{
 					## Put up no create allowed dialog
-					$self->{'Configure'}{'-EDlgText'} = "You must specify an existing directory.\n($fname not found)";
-					$self->Dialog(-title => $self->{'Configure'}{'-EDlgTitle'},
-							-text => $self->{'Configure'}{'-EDlgText'},
+					$self->{'Configure'}{'-EDlgText'} = "You must specify an existing directory.\n(\$fname not found)";
+					eval "\$self->${dialog_widget}(-title => \$self->{'Configure'}{'-EDlgTitle'},
+							-text => \$self->{'Configure'}{'-EDlgText'},
 							-bitmap => 'error'
-					)->Show;
+					)->Show";
 
 					return;
 				}
@@ -1895,10 +1929,10 @@ FILELOOP3:				foreach my $f (@filelist)   #ADD FULL PATHS TO ANY THAT ARE MISSIN
 				{
 					$self->{'Configure'}{'-EDlgText'} = "Only a single file is allowed!\n" 
 							. $self->{'Configure'}{'-File'} . "\nrepresents multiple files.";
-					$self->Dialog(-title => $self->{'Configure'}{'-EDlgTitle'},
-								-text => $self->{'Configure'}{'-EDlgText'},
+					eval "\$self->${dialog_widget}(-title => \$self->{'Configure'}{'-EDlgTitle'},
+								-text => \$self->{'Configure'}{'-EDlgText'},
 								-bitmap => 'error'
-					)->Show;
+					)->Show";
 
 					return;
 				}
@@ -1913,9 +1947,27 @@ FILELOOP3:				foreach my $f (@filelist)   #ADD FULL PATHS TO ANY THAT ARE MISSIN
 				my @filelist = split (/\,/, $fname);
 				my $filenames = '';
 				my $errnames = '';
-				my @filters = defined ($self->{'Configure'}{'-FPatFilters'})
-						? split (/\|/o, $self->{'Configure'}{'-FPatFilters'}) : ();
+				my $protected = defined ($self->{'Configure'}{'-FPatFilters'})
+						? $self->{'Configure'}{'-FPatFilters'} : '';
+				my @filters = ();
+				if ($protected)
+				{
+					$protected =~ s#\\\|#\x04#g;
+					@filters = split (/\|/o, $protected);
+				}
 				@filters = ('')  unless ($#filters >= 0);
+				my @filters_rgx = ();
+				foreach my $f (@filters)
+				{
+					$f =~ s#\x04#\|#g;     #UNPROTECT AND UNESCAPE ESCAPED SEPARATOR ("\|").
+					$f =~ s#\\\.#\x02#go;  #PROTECT ESCAPED SPECIAL CHARACTERS:
+					$f =~ s#\\\*#\x03#go;
+					$f =~ s#\.#\\\.#go;    #CONVERT PATTERN TO PROPER PERL REGEX:
+					$f =~ s#\*#\.\*#go;    #("*" MUST BE ".*", SO WE TREAT "\*" AS "*")!
+					$f =~ s#\x03#\\\*#go;  #UNPROTECT ESCAPED SPECIAL CHARACTERS:
+					$f =~ s#\x02#\.#go;    #(WE TREAT "." AS "\." (MATCH ".") AND "\." AS "." (WILDCARD))!
+					push @filters_rgx, $f;
+				}
 FILELOOP4:				foreach my $f (@filelist)
 				{
 #					if ($self->{'Configure'}{'-Create'} > 0 || -f $f)   #SEPARATE THE SHEEP FROM THE GOATS:
@@ -1926,7 +1978,7 @@ FILELOOP4:				foreach my $f (@filelist)
 							$filenames .= $f . ',';
 							next;
 						}
-						foreach my $filter (@filters)
+						foreach my $filter (@filters_rgx)
 						{
 							if ($f =~ /^${filter}$/)
 							{
@@ -1959,9 +2011,9 @@ FILELOOP4:				foreach my $f (@filelist)
 							if ($self->{'Configure'}{'-SelectMode'} =~ /(?:multiple|extended)/i);
 					$self->{'Configure'}{'-EDlgText'} = "You must specify ${errdesc}.\n"
 							. "($errnames)";
-					$self->Dialog(-title => $self->{'Configure'}{'-EDlgTitle'},
-							-text => $self->{'Configure'}{'-EDlgText'},
-							-bitmap => 'error')->Show;
+					eval "\$self->${dialog_widget}(-title => \$self->{'Configure'}{'-EDlgTitle'},
+							-text => \$self->{'Configure'}{'-EDlgText'},
+							-bitmap => 'error')->Show";
 
 					return;
 				}
@@ -1974,11 +2026,11 @@ FILELOOP4:				foreach my $f (@filelist)
 			if ($self->{'Configure'}{'-Create'} <= 0 && !$self->_fidtest('-d', $fname))
 			{
 				## Put up no create allowed dialog
-				$self->{'Configure'}{'-EDlgText'} = "You must specify an existing directory.\n($fname not found)";
-				$self->Dialog(-title => $self->{'Configure'}{'-EDlgTitle'},
-						-text => $self->{'Configure'}{'-EDlgText'},
+				$self->{'Configure'}{'-EDlgText'} = "You must specify an existing directory.\n(\$fname not found)";
+				eval "\$self->${dialog_widget}(-title => \$self->{'Configure'}{'-EDlgTitle'},
+						-text => \$self->{'Configure'}{'-EDlgText'},
 						-bitmap => 'error'
-				)->Show;
+				)->Show";
 
 				return;
 			}
@@ -2107,7 +2159,7 @@ widget for Perl/Tk.
 
 =head1 AUTHOR
 
-(c) 1996-2019, Jim Turner, C<< <https://metacpan.org/author/TURNERJW> >>.
+(c) 1996-2023, Jim Turner, C<< <https://metacpan.org/author/TURNERJW> >>.
 
 =head1 ACKNOWLEDGEMENTS
 
@@ -2115,7 +2167,7 @@ This is a derived work from Tk::FileDialog, Tk::Listbox and Tk::HList.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 1996-2019 Jim Turner C<< <mailto:turnerjw784@yahoo.com> >>.
+Copyright (c) 1996-2023 Jim Turner C<< <mailto:turnerjw784@yahoo.com> >>.
 All rights reserved.  
 
 Tk::JFileDialog is free software; you can redistribute it and/or
@@ -2196,7 +2248,7 @@ required.
 
 	MainLoop;
 
-	print "Exit Stage right!\n";
+	print "Exiting!\n";
 
 	exit(0);
 
@@ -2207,15 +2259,16 @@ It uses and depends on the author's Tk::JBrowseEntry widget and adds
 numerous features, such as optional history and favorites files, 
 handles MS-Windows drive letters, additional key bindings, etc.
 
-To use JFileDialog, simply create your JFileDialog objects during initialization (or at
-least before a Show).  When you wish to display the JFileDialog, invoke the 'Show' method
-on the JFileDialog object;  The method will return either a file name, a path name, or
-undef.  undef is returned only if the user pressed the Cancel button.
+To use JFileDialog, simply create your JFileDialog objects during 
+initialization (or at least before a Show).  When you wish to display the 
+JFileDialog, invoke the 'Show' method on the JFileDialog object;  The method 
+will return either a file name, a path name, or undef.  undef is returned only 
+if the user pressed the Cancel button.
 
 =head1 WIDGET OPTIONS
 
-Any of the following configuration items may be set via the configure (or Show) method,
-or retrieved via the cget method:
+Any of the following configuration items may be set via the configure 
+(or Show) method, or retrieved via the cget method:
 
 =over 4
 
@@ -2226,38 +2279,44 @@ and the user specifies a non-existent file, a dialog box will be shown
 informing the user of the error (This Dialog Box is configurable via the 
 B<EDlg*> switches, described below).  If set to I<-1>, user can not create 
 a new file nor type in a name, only select from the list.  
+
 Default:  I<1> (enable user to enter a "new" (non-existant) file name).
 
 =item B<-DisableFPat>
 
-Disables the ability of the user to change the file selection pattern (the user is 
-by default allowed to change the status).  
+Disables the ability of the user to change the file selection pattern 
+(the user is by default allowed to change the status).  
+
 Default:  I<FALSE> (enable user to change the file selection pattern).
 
 =item B<-DisableShowAll>
 
 Disables the ability of the user to change the status of 
 the ShowAll flag (the user is by default allowed to change the status).  
-Default:  I<FALSE> (enable user to toggle showing of hidden files and directories).
+
+Default:  I<FALSE> (enable user to toggle showing of hidden files 
+and directories).
 
 =item B<-File>
 
 The default file name.  If specified and the file exists 
-in the currently-selected path, it will be highlighted and selected; and pressing 
-the [Reset] button will reset the selected file to be this one.  
-Default:  none (no default file name is initially shown).
+in the currently-selected path, it will be highlighted and selected; and 
+pressing the [Reset] button will reset the selected file to be this one.  
+
+Default:  I<none> (no default file name is initially shown).
 
 =item B<-FNameList>
 
 Optional reference to a list of specific file names to be displayed in the file 
 list.  User can be forced to select a file from this specific list by further 
 constraints such as B<-DisableFPat> => 1, B<-Create> => -1, B<-SelDir> => -1, 
-and B<-DisableShowAll> => 1.  The list can contain any combination of file names 
-(ie. I<"file.ext">, absolute paths, ie. I<"/home/user/file.ext">, or relative paths, 
-ie. I<"user/file.ext"> or I"<c:file.ext>.  The files will be compared against the 
-current path and, if matching (and existing, if B<-Create> < 1), will be shown in 
-the drop-down list.  
-Default:  none (show all files otherwise matching any other filters 
+and B<-DisableShowAll> => 1.  The list can contain any combination of file 
+names (ie. I<"file.ext">, absolute paths, ie. I<"/home/user/file.ext">, or 
+relative paths, ie. I<"user/file.ext"> or I"<c:file.ext>.  The files will be 
+compared against the current path and, if matching (and existing, 
+if B<-Create> < 1), will be shown in the drop-down list.  
+
+Default:  I<none> (show all files otherwise matching any other filters 
 found in the current path.  
 
 NOTE:  File-names are case-sensitive and paths should be forward 
@@ -2266,39 +2325,52 @@ slashes ("/"), even on M$-Windows.
 =item B<-FPat>
 
 Sets the default file selection pattern.  Only files matching this pattern will 
-be displayed in the File List Box.  It can also be multiple extensions separated by 
-the pipe symbol ("|"), ie. "*.jpg|*.gif|*.png".  
+be displayed in the File List Box.  It can also be multiple extensions 
+separated by the pipe symbol ("|"), ie. "*.jpg|*.gif|*.png".  
+
+NOTE:  The "pattern" is a psuedo-regex that gets converted into a Perl regex, 
+but "*" is converted into ".*", "." is converted into "\." (match literal 
+I<dot>, "\." is converted to ".", and "|" used in a pattern must be escaped 
+("\|") as "|" is the separator character in pattern lists!
+
 Default:  I<''> (*).
 
 =item B<-FPatList>
 
-Specifies a reference to a list of valid file extensions composing the drop-down 
-list for the "Filter" field for selecting a file selection pattern.  Default is 
-empty.  Example:  B<-FPatList> => ['*.jpg|*.gif|*.png', '*.pl|*.pm', '*.exe'].  
-NOTE:  If B<-Fpat> is also specified, but is NOT in the B<-FPatList> list, it will 
-automatically be appended to the top of the list.
+Specifies a reference to a list of valid file extensions composing the 
+drop-down list for the "Filter" field for selecting a file selection pattern.  
+
+Default:  I<empty ('')>.  
+
+Example:  B<-FPatList> => ['*.jpg|*.gif|*.png', '*.pl|*.pm', '*.exe'].  
+NOTE:  If B<-Fpat> is also specified, but is NOT in the B<-FPatList> list, it 
+will automatically be appended to the top of the list.
 
 =item B<-FPatOnly>
 
-Compares all files selected or typed in against the file selection pattern, if set 
-to 1.  This, combined with B<-FPat> and / or B<-FPatList> can force a user to enter 
-files with the proper extension.
+Compares all files selected or typed in against the file selection pattern, 
+if set to 1.  This, combined with B<-FPat> and / or B<-FPatList> can force a 
+user to enter files with the proper extension.
 
 =item B<-Geometry>
 
-Sets the geometry of the File Dialog. Setting the size is a dangerous thing to do.
-If not configured, or set to '', the File Dialog will be centered.  Default: undef 
-(window-manager sets the popup window's geometry).
+Sets the geometry of the File Dialog. Setting the size is a dangerous thing 
+to do.  If not configured, or set to '', the File Dialog will be centered.  
+
+Default:  I<undef> (window-manager sets the popup window's geometry).
 
 =item B<-Grab>
 
-Enables the File Dialog to do an application Grab when displayed.  Default: 1 
-(file dialog will grab focus and be "modal").
+Enables the File Dialog to do an application Grab when displayed.  
+
+Default:  I<1> (file dialog will grab focus and be "modal").
 
 =item B<-HistDeleteOk>
 
-If set, allows user to delete items from the history dropdown list and thus the 
-history file.  Default 0 (do not allow user to remove items in history).
+If set, allows user to delete items from the history dropdown list and thus 
+the history file.  
+
+Default:  I<0> (false)> (do not allow user to remove items in history).
 
 NOTE:  requires Tk::JBrowseEntry v5.0 or later to work.
 
@@ -2306,8 +2378,9 @@ NOTE:  requires Tk::JBrowseEntry v5.0 or later to work.
 
 Enables the keeping of a history of the previous files / directories selected.  
 The file specified must be writable.  If specified, a history of up to 
-"-History" number of files will be kept and will be displayed in a "JBrowseEntry" 
-combo-box permitting user selection.  
+"-History" number of files will be kept and will be displayed in a 
+"JBrowseEntry" combo-box permitting user selection.  
+
 Default:  I<undef> (no history file or drop-down).
 
 =item B<-History>
@@ -2323,35 +2396,41 @@ If set to something other than 1 or 0, a checkbox will appear to the right
 of the history dropdown labeled "Keep Path" to allow user to control this.
 If set to a string, then that will be used for the checkbox label in lieu of 
 "Keep Path".  
+
 Default:  I<undef> (not set).
 
 =item B<-HistUsePathButton>
 
-Set (check or uncheck) the "Keep Path" checkbox created if "-HistUsePath" option 
-is set, otherwise, ignored.  The state of this button can also be fetched by 
-calling the B<getHistUsePathButton()> method, which returns 1 or 0.  
-Default:  I<FALSE> (unchecked).
+Set (check or uncheck) the "Keep Path" checkbox created if "-HistUsePath" 
+option is set, otherwise, ignored.  The state of this button can also be 
+fetched by calling the B<getHistUsePathButton()> method, which returns 1 or 0. 
+
+Default:  I<0 (false)> (unchecked).
 
 =item B<-Horiz>
 
-I<TRUE> sets the File List box to be to the right of the Directory List Box. If 0, the
-File List box will be below the Directory List box.  
-Default:  I<TRUE> (display the listboxes side-by-side).
+I<TRUE> sets the File List box to be to the right of the Directory List Box.  
+If 0, the File List box will be below the Directory List box.  
+
+Default:  I<true> (display the listboxes side-by-side).
 
 =item B<-maxwidth>
 
-Specifies the maximum width in avg. characters the width of the text entry fields 
-are allowed to expand to.  
+Specifies the maximum width in avg. characters the width of the text entry 
+fields are allowed to expand to.  
+
 Default:  I<60> (characters).
 
 =item B<-nonLatinFilenames>
 
 B<NEW> with Version 2.11+:
 
-If set, allows for handling of non-Latin / unicode file-names that Perl doesn't, 
-by default, seem to handle properly as of 5.28.1, as it wants to convert them 
-to utf-8 internally, but then fails to find / match them with the underling 
-file-system names (they likely won't show up in the file / directory lists).  
+If set, allows for handling of non-Latin / unicode file-names that Perl 
+doesn't, by default, seem to handle properly as of 5.28.1, as it wants to 
+convert them to utf-8 internally, but then fails to find / match them with the 
+underling file-system names (they likely won't show up in the file / 
+directory lists).  
+
 Default:  I<0> (unset - only handle normal (ANSI chars < 128) characters in 
 file-names, as was the case pre-v2.11).  
 
@@ -2387,74 +2466,87 @@ Default:  I<undef> (no favorite path file or dropdown list).
 
 =item B<-QuickSelect>
 
-If set to 0, user must invoke the "OK" button to complete selection 
-from the listbox.  If 1 or 2, double-clicking or single-clicking (respectively) an 
-item in the file list automatically completes the selection.  NOTE:  If set to 2 
-(single-click) and I<-SelectMode> is "multiple" or "extended" then it will be 
-forced to 1 (double-click), since single-click will just add the file to the 
-list to be selected.  This also affects the history and favorite path dropdown 
-lists.  If 1 or 2, clicking an item from these lists invokes selection.  
+If set to 0, user must invoke the "OK" button to complete selection from 
+the listbox.  If 1 or 2, double-clicking or single-clicking (respectively) an 
+item in the file list automatically completes the selection.  
+
+NOTE:  If set to 2 (single-click) and I<-SelectMode> is "multiple" or 
+"extended" then it will be forced to 1 (double-click), since single-click will 
+just add the file to the list to be selected.  This also affects the history 
+and favorite path dropdown lists.  If 1 or 2, clicking an item from these 
+lists invokes selection.  
+
 Default:  I<1>.
 
 =item B<-SelDir>
 
-If 1 or 2, enables selection of a directory rather than a file, and disables the
-actions of the File List Box. Setting to 2 allows selection of either a file OR a 
-directory.  If -1, the directory listbox, etc. are disabled and the user is forced 
-to select file(s) from the initially-specified path.  NOTE:  This will NOT prevent 
-the user from typing an alternate path in front of the file name entered, so the 
-application must still verify the path returned and handle as desired, ie. display 
-an error dialog and force them to reenter, strip the path, etc.  
+If 1 or 2, enables selection of a directory rather than a file, and disables 
+theactions of the File List Box. Setting to 2 allows selection of either a 
+file OR a directory.  If -1, the directory listbox, etc. are disabled and the 
+user is forced to select file(s) from the initially-specified path.  
+
+NOTE:  This will NOT prevent the user from typing an alternate path in front 
+of the file name entered, so the application must still verify the path 
+returned and handle as desired, ie. display an error dialog and force them to 
+reenter, strip the path, etc.  
+
 Default:  I<0> (only file(s) may be selected).
 
 =item B<-SelectMode>
  
-Sets the selectmode of the File Dialog.  If not configured it will be defaulted
-to 'browse' (single).  If set to 'multiple' or 'extended', then the user may select 
-more than one file and a comma-delimited list of all selected files is returned.  
-Otherwise, only a single file may be selected.  
+Sets the selectmode of the File Dialog.  If not configured it will be 
+defaulted to 'browse' (single).  If set to 'multiple' or 'extended', then the 
+user may select more than one file and a comma-delimited list of all selected 
+files is returned.  Otherwise, only a single file may be selected.  
+
 Default: I<'browse'> (selecting only a single file from the list allowed).
  
 =item B<-SelHook>
 
-SelHook is configured with a reference to a routine that will be called when a file
-is chosen. The file is called with a sole parameter of the full path and file name
-of the file chosen. If the Create flag is disabled (and the user is not allowed
-to specify new files), the file will be known to exist at the time that SelHook is
-called. Note that SelHook will also be called with directories if the SelDir Flag
-is enabled, and that the JFileDialog box will still be displayed. The JFileDialog box
-should B<not> be destroyed from within the SelHook routine, although it may generally
-be configured.
+SelHook is configured with a reference to a routine that will be called when 
+a fileis chosen. The file is called with a sole parameter of the full path and 
+file nameof the file chosen. If the Create flag is disabled (and the user is 
+not allowedto specify new files), the file will be known to exist at the time 
+that SelHook is called. Note that SelHook will also be called with directories 
+if the SelDir Flag is enabled, and that the JFileDialog box will still be 
+displayed.  The JFileDialog box should B<not> be destroyed from within the 
+SelHook routine, although it may generally be configured.
 
-SelHook routines return 0 to reject the selection and allow the user to reselect, and
-any other value to accept the selection. If a SelHook routine returns non-zero, the
-JFileDialog will immediately be withdrawn, and the file will be returned to the caller.
+SelHook routines return 0 to reject the selection and allow the user to 
+reselect, and any other value to accept the selection. If a SelHook routine 
+returns non-zero, the JFileDialog will immediately be withdrawn, and the file 
+will be returned to the caller.
+
+There may be only one SelHook routine active at any time. Configuring the 
+SelHook routine replaces any existing SelHook routine. Configuring the SelHook 
+routine with 0 removes the SelHook routine.  
 
-There may be only one SelHook routine active at any time. Configuring the SelHook
-routine replaces any existing SelHook routine. Configuring the SelHook routine with
-0 removes the SelHook routine.  
 Default:  I<undef> (no callback function).
 
 =item B<-ShowAll>
 
-Determines whether hidden files and directories (.* and those with the M$-Windows "hidden" 
-attribute set, on Windows) are displayed in the File and Directory Listboxes.  
-The Show All Checkbox reflects the setting of this switch.  
+Determines whether hidden files and directories (.* and those with the 
+M$-Windows "hidden" attribute set, on Windows) are displayed in the File and 
+Directory Listboxes.  The Show All Checkbox reflects the setting of 
+this switch.  
+
 Default:  I<0> (do not show hidden files or directories).
 
 =item B<-ShowDirList>
 
 Enable the user to change directories.  If disabled, the directory
-list box will not be shown.  Generally, I<-SelDir> should also be set to -1, otherwise, 
-user can still change directories by typing them in.  
-Default:  I<TRUE> (enable).
+list box will not be shown.  Generally, I<-SelDir> should also be set to -1, 
+otherwise, user can still change directories by typing them in.  
+
+Default:  I<true> (enable).
 
 =item B<-ShowFileList>
 
 Enable the user to select file(s) from a list.  If disabled, the file 
-list box will not be shown.  Generally, I<-SelDir> should also be set to 1, otherwise, 
-user can still select files by typing them in.  
-Default:  I<TRUE> (enable).
+list box will not be shown.  Generally, I<-SelDir> should also be set to 1, 
+otherwise, user can still select files by typing them in.  
+
+Default:  I<true> (enable).
 
 =item B<-Title>
 
@@ -2465,79 +2557,93 @@ Default:  I<'Select File:'>.
 
 =head2 B<Labels and Captions>
 
-For support of internationalization, the text on any of the subwidgets may be
-changed.
+For support of internationalization, the text on any of the subwidgets may 
+be changed.
 
 =over 4
 
 =item B<-CancelButtonLabel>
 
 The text for the Cancel button.  
+
 Default: I<'Cancel'>.
 
 =item B<-CdoutButtonLabel>
 
 The text for the JFM4 Filemanager "Current" Directory button. 
+
 Default: I<'C~dout'>.
 
 =item B<-CWDButtonLabel>
 
 The text for the Cdout Directory button.  
+
 Default: I<'C~WD'>.
 
 =item B<-DirLBCaption>
 
 The Caption above the Directory List Box.  
+
 Default: I<'Folders:'> on Windows sytems, I<'Directories:'> on all others.
 
 =item B<-FileEntryLabel>
 
 The label to the left of the File Entry.  
+
 Default: I<'File:'>.
 
 =item B<-FltEntryLabel>
 
 The label to the left of the Filter entry.  
+
 Default:  I<'Filter:'>.
 
 =item B<-FileLBCaption>
 
 The Caption above the File List Box.  
+
 Default:  I<'Files'>.
 
 =item B<-HomeButtonLabel>
 
 The text for the Home directory button.  
+
 Default:  I<'Home'>.
 
 =item B<-OKButtonLabel>
 
 The text for the OK button.  
+
 Default:  I<'Ok'>.
 
 =item B<-PathEntryLabel>
 
 The label to the left of the Path Entry.  
+
 Default:  I<'Path:'>.
 
 =item B<-RescanButtonLabel>
 
 The text for the Rescan button.  
+
 Default:  I<'Refresh'>.
 
 =item B<-ResetButtonLabel>
 
 The text for the Reset button.  
+
 Default:  I<'Re~set'>.
 
 =item B<-ShowAllLabel>
 
 The text of the Show All Checkbutton.  
+
 Default:  I<'Show All'>.
 
 =item B<-SortButton>
 
 Whether or not to display a checkbox to change file box list sort order.  
+
 Default:  I<TRUE> (show).
 
 =item B<-SortButtonLabel>
@@ -2548,10 +2654,11 @@ Default:  I<'Atime'>.
 =item B<-SortOrder>
 
 Order to display files in the file list box ('Name' or 'Date')
-Default:  I<Name>.
 If I<'Date'>, then the day and time is displayed in the box before 
 the name, (but not included when selected)
 
+Default:  I<Name>.
+
 =back
 
 =head2 B<Error Dialog Switches>
@@ -2567,11 +2674,13 @@ of the error. These switches allow some configuration of that dialog box.
 DEPRECIATED (now ignored)! - The message of the Error Dialog Box.  
 The variables $path, $file, and $filename
 (the full path and filename of the selected file) are available.  
+
 Default:  I<"You must specify an existing file.\n(\$filename not found)">.
 
 =item B<-EDlgTitle>
 
 The title of the Error Dialog Box.  
+
 Default:  I<'Incorrect entry or selection!'>.
 
 =back
@@ -2584,7 +2693,7 @@ The following non-standard methods may be used with a JFileDialog object
 
 =item B<Show()>
 
-Displays the file dialog box for the user to operate.  Additional configuration
+Displays the file dialog box for the user to operate.  Additional configuration 
 items may be passed in at Show-time In other words, this code snippet:
 Returns nothing.
 
@@ -2598,29 +2707,34 @@ is the same as this code snippet:
 
 =item B<getHistUsePathButton()>
 
-Fetches the value of the "Keep Path" checkbox created by setting the B<-HistUsePath> 
-option.  The checkbox can be set initially by the B<-HistUsePathButton>.  The purpose of 
-this allows an application to "remember" the user's last choice for this checkbox the next 
-time he invokes the JFileDialog widget by fetching it's status via this function after 
-the JFileDialog widget is closed when the user last selected a file, etc., then using that 
-variable as the I<HistUsePathButton> argument when JFileDialog is opened again within the 
-application.  
+Fetches the value of the "Keep Path" checkbox created by setting the 
+B<-HistUsePath> option.  The checkbox can be set initially by the 
+B<-HistUsePathButton>.  The purpose of this allows an application to 
+"remember" the user's last choice for this checkbox the next time he invokes 
+the JFileDialog widget by fetching it's status via this function after the 
+JFileDialog widget is closed when the user last selected a file, etc., then 
+using that variable as the I<HistUsePathButton> argument when JFileDialog is 
+opened again within the application.
+
 Returns integer (1 or 0).
 
 =item B<getLastPath()>
 
-Fetches the current path as it was when the JFileDialog wiget last closed.  The purpose of 
-this allows an application to "remember" the path the previous user selected from the next 
-time he invokes the JFileDialog widget by fetching it's status via this function after 
-the JFileDialog widget is closed when the user last selected a file, etc., then using that 
-variable as the I<-Path> argument when JFileDialog is opened again within the application.  
-Returns I<string> (last path user selected, if known, otherwise the path specified by 
-B<-Path>, if specified, or the current working directory).
+Fetches the current path as it was when the JFileDialog wiget last closed.  
+The purpose of this allows an application to "remember" the path the previous 
+user selected from the next time he invokes the JFileDialog widget by fetching 
+it's status via this function after the JFileDialog widget is closed when the 
+user last selected a file, etc., then using that variable as the I<-Path> 
+argument when JFileDialog is opened again within the application.  
+
+Returns I<string> (last path user selected, if known, otherwise the path 
+specified by B<-Path>, if specified, or the current working directory).
 
 =back
 
 =head1 DEPENDS
 
-Cwd, L<File::Glob>, L<Tk>, L<Tk::Dialog> L<Tk::JBrowseEntry>
+Cwd, L<File::Glob>, L<Tk>, L<Tk::Dialog> (or L<Tk::JDialog> if installed), 
+L<Tk::JBrowseEntry>
 
 =cut
